==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/ContextFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ContextFluentImpl<A extends io.fabric8.kubernetes.api.model.ContextFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ContextFluent<A>{
  public ContextFluentImpl() {
  }
  public ContextFluentImpl(io.fabric8.kubernetes.api.model.Context instance) {
    this.withCluster(instance.getCluster()); 
    this.withExtensions(instance.getExtensions()); 
    this.withNamespace(instance.getNamespace()); 
    this.withUser(instance.getUser()); 
  }
  private java.lang.String cluster;
  private java.util.List<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> extensions =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();
  private java.lang.String namespace;
  private java.lang.String user;
  public java.lang.String getCluster() {
    return this.cluster;
  }
  public A withCluster(java.lang.String cluster) {
    this.cluster=cluster; return (A) this;
  }
  public java.lang.Boolean hasCluster() {
    return this.cluster != null;
  }
  
  /**
   * Method is deprecated. use withCluster instead.
   */
  @java.lang.Deprecated
  public A withNewCluster(java.lang.String arg0) {
    return (A)withCluster(new String(arg0));
  }
  public A addToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").add(index >= 0 ? index : _visitables.get("extensions").size(), builder);this.extensions.add(index >= 0 ? index : extensions.size(), builder); return (A)this;
  }
  public A setToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);
    if (index < 0 || index >= _visitables.get("extensions").size()) { _visitables.get("extensions").add(builder); } else { _visitables.get("extensions").set(index, builder);}
    if (index < 0 || index >= extensions.size()) { extensions.add(builder); } else { extensions.set(index, builder);}
     return (A)this;
  }
  public A addToExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").add(builder);this.extensions.add(builder);} return (A)this;
  }
  public A addAllToExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").add(builder);this.extensions.add(builder);} return (A)this;
  }
  public A removeFromExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items) {
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").remove(builder);if (this.extensions != null) {this.extensions.remove(builder);}} return (A)this;
  }
  public A removeAllFromExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items) {
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").remove(builder);if (this.extensions != null) {this.extensions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromExtensions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    if (extensions == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> each = extensions.iterator();
    final List visitables = _visitables.get("extensions");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildExtensions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> getExtensions() {
    return build(extensions);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> buildExtensions() {
    return build(extensions);
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildExtension(java.lang.Integer index) {
    return this.extensions.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildFirstExtension() {
    return this.extensions.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildLastExtension() {
    return this.extensions.get(extensions.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.NamedExtensionBuilder item: extensions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.NamedExtensionBuilder item: extensions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExtensions(java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> extensions) {
    if (this.extensions != null) { _visitables.get("extensions").removeAll(this.extensions);}
    if (extensions != null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>(); for (io.fabric8.kubernetes.api.model.NamedExtension item : extensions){this.addToExtensions(item);}} else { this.extensions = null;} return (A) this;
  }
  public A withExtensions(io.fabric8.kubernetes.api.model.NamedExtension... extensions) {
    if (this.extensions != null) {this.extensions.clear();}
    if (extensions != null) {for (io.fabric8.kubernetes.api.model.NamedExtension item :extensions){ this.addToExtensions(item);}} return (A) this;
  }
  public java.lang.Boolean hasExtensions() {
    return extensions != null && !extensions.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> addNewExtension() {
    return new io.fabric8.kubernetes.api.model.ContextFluentImpl.ExtensionsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> addNewExtensionLike(io.fabric8.kubernetes.api.model.NamedExtension item) {
    return new io.fabric8.kubernetes.api.model.ContextFluentImpl.ExtensionsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> setNewExtensionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
    return new io.fabric8.kubernetes.api.model.ContextFluentImpl.ExtensionsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editExtension(java.lang.Integer index) {
    if (extensions.size() <= index) throw new RuntimeException("Can't edit extensions. Index exceeds size.");
    return setNewExtensionLike(index, buildExtension(index));
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editFirstExtension() {
    if (extensions.size() == 0) throw new RuntimeException("Can't edit first extensions. The list is empty.");
    return setNewExtensionLike(0, buildExtension(0));
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editLastExtension() {
    int index = extensions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last extensions. The list is empty.");
    return setNewExtensionLike(index, buildExtension(index));
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<extensions.size();i++) { 
    if (predicate.test(extensions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching extensions. No match found.");
    return setNewExtensionLike(index, buildExtension(index));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public java.lang.String getUser() {
    return this.user;
  }
  public A withUser(java.lang.String user) {
    this.user=user; return (A) this;
  }
  public java.lang.Boolean hasUser() {
    return this.user != null;
  }
  
  /**
   * Method is deprecated. use withUser instead.
   */
  @java.lang.Deprecated
  public A withNewUser(java.lang.String arg0) {
    return (A)withUser(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContextFluentImpl that = (ContextFluentImpl) o;
    if (cluster != null ? !cluster.equals(that.cluster) :that.cluster != null) return false;
    if (extensions != null ? !extensions.equals(that.extensions) :that.extensions != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  extensions,  namespace,  user,  super.hashCode());
  }
  public class ExtensionsNestedImpl<N> extends io.fabric8.kubernetes.api.model.NamedExtensionFluentImpl<io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<N>> implements io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ExtensionsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(this, item);
    }
    ExtensionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ContextFluentImpl.this.setToExtensions(index,builder.build());
    }
    public N endExtension() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/ContextFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ContextFluentImpl<A extends io.fabric8.kubernetes.api.model.ContextFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ContextFluent<A>{
  public ContextFluentImpl() {
  }
  public ContextFluentImpl(io.fabric8.kubernetes.api.model.Context instance) {
    this.withCluster(instance.getCluster()); 
    this.withExtensions(instance.getExtensions()); 
    this.withNamespace(instance.getNamespace()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String cluster;
  private java.util.List<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> extensions =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();
  private java.lang.String namespace;
  private java.lang.String user;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCluster() {
    return this.cluster;
  }
  public A withCluster(java.lang.String cluster) {
    this.cluster=cluster; return (A) this;
  }
  public java.lang.Boolean hasCluster() {
    return this.cluster != null;
  }
  
  /**
   * Method is deprecated. use withCluster instead.
   */
  @java.lang.Deprecated
  public A withNewCluster(java.lang.String arg0) {
    return (A)withCluster(new String(arg0));
  }
  public A addToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").add(index >= 0 ? index : _visitables.get("extensions").size(), builder);this.extensions.add(index >= 0 ? index : extensions.size(), builder); return (A)this;
  }
  public A setToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);
    if (index < 0 || index >= _visitables.get("extensions").size()) { _visitables.get("extensions").add(builder); } else { _visitables.get("extensions").set(index, builder);}
    if (index < 0 || index >= extensions.size()) { extensions.add(builder); } else { extensions.set(index, builder);}
     return (A)this;
  }
  public A addToExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").add(builder);this.extensions.add(builder);} return (A)this;
  }
  public A addAllToExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items) {
    if (this.extensions == null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>();}
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").add(builder);this.extensions.add(builder);} return (A)this;
  }
  public A removeFromExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items) {
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").remove(builder);if (this.extensions != null) {this.extensions.remove(builder);}} return (A)this;
  }
  public A removeAllFromExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items) {
    for (io.fabric8.kubernetes.api.model.NamedExtension item : items) {io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(item);_visitables.get("extensions").remove(builder);if (this.extensions != null) {this.extensions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromExtensions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    if (extensions == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> each = extensions.iterator();
    final List visitables = _visitables.get("extensions");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildExtensions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> getExtensions() {
    return build(extensions);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> buildExtensions() {
    return build(extensions);
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildExtension(java.lang.Integer index) {
    return this.extensions.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildFirstExtension() {
    return this.extensions.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildLastExtension() {
    return this.extensions.get(extensions.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.NamedExtension buildMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.NamedExtensionBuilder item: extensions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.NamedExtensionBuilder item: extensions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExtensions(java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> extensions) {
    if (this.extensions != null) { _visitables.get("extensions").removeAll(this.extensions);}
    if (extensions != null) {this.extensions = new java.util.ArrayList<io.fabric8.kubernetes.api.model.NamedExtensionBuilder>(); for (io.fabric8.kubernetes.api.model.NamedExtension item : extensions){this.addToExtensions(item);}} else { this.extensions = null;} return (A) this;
  }
  public A withExtensions(io.fabric8.kubernetes.api.model.NamedExtension... extensions) {
    if (this.extensions != null) {this.extensions.clear();}
    if (extensions != null) {for (io.fabric8.kubernetes.api.model.NamedExtension item :extensions){ this.addToExtensions(item);}} return (A) this;
  }
  public java.lang.Boolean hasExtensions() {
    return extensions != null && !extensions.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> addNewExtension() {
    return new io.fabric8.kubernetes.api.model.ContextFluentImpl.ExtensionsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> addNewExtensionLike(io.fabric8.kubernetes.api.model.NamedExtension item) {
    return new io.fabric8.kubernetes.api.model.ContextFluentImpl.ExtensionsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> setNewExtensionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
    return new io.fabric8.kubernetes.api.model.ContextFluentImpl.ExtensionsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editExtension(java.lang.Integer index) {
    if (extensions.size() <= index) throw new RuntimeException("Can't edit extensions. Index exceeds size.");
    return setNewExtensionLike(index, buildExtension(index));
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editFirstExtension() {
    if (extensions.size() == 0) throw new RuntimeException("Can't edit first extensions. The list is empty.");
    return setNewExtensionLike(0, buildExtension(0));
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editLastExtension() {
    int index = extensions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last extensions. The list is empty.");
    return setNewExtensionLike(index, buildExtension(index));
  }
  public io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<A> editMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<extensions.size();i++) { 
    if (predicate.test(extensions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching extensions. No match found.");
    return setNewExtensionLike(index, buildExtension(index));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public java.lang.String getUser() {
    return this.user;
  }
  public A withUser(java.lang.String user) {
    this.user=user; return (A) this;
  }
  public java.lang.Boolean hasUser() {
    return this.user != null;
  }
  
  /**
   * Method is deprecated. use withUser instead.
   */
  @java.lang.Deprecated
  public A withNewUser(java.lang.String arg0) {
    return (A)withUser(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContextFluentImpl that = (ContextFluentImpl) o;
    if (cluster != null ? !cluster.equals(that.cluster) :that.cluster != null) return false;
    if (extensions != null ? !extensions.equals(that.extensions) :that.extensions != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  extensions,  namespace,  user,  additionalProperties,  super.hashCode());
  }
  public class ExtensionsNestedImpl<N> extends io.fabric8.kubernetes.api.model.NamedExtensionFluentImpl<io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<N>> implements io.fabric8.kubernetes.api.model.ContextFluent.ExtensionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ExtensionsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(this, item);
    }
    ExtensionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.NamedExtensionBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NamedExtensionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ContextFluentImpl.this.setToExtensions(index,builder.build());
    }
    public N endExtension() {
      return and();
    }
    
  }
  
}
